@@ -1,13 +1,13 @@
 package Pg::CLI::Role::HasVersion;
 BEGIN {
-  $Pg::CLI::Role::HasVersion::VERSION = '0.06';
+  $Pg::CLI::Role::HasVersion::VERSION = '0.07';
 }
 
 use Moose::Role;
 
 use namespace::autoclean;
 
-use IPC::System::Simple qw( systemx );
+use IPC::System::Simple qw( capturex );
 use MooseX::Types::Moose qw( Str );
 use Pg::CLI::pg_config;
 
@@ -30,7 +30,7 @@ has two_part_version => (
 sub _build_version {
     my $self = shift;
 
-    my $output = systemx( $self->executable(), '--version' );
+    my $output = capturex( $self->executable(), '--version' );
 
     return $1 if $output =~ /(\d\.\d\.\d)/;
 }
